@@ -477,20 +477,21 @@ class PlotFormatter(Formatter):
         titles = []
         if settings.PRINT_TITLE:
             plot_title = settings.DESCRIPTION
+            y=0.98
             if 'description' in self.config:
                 plot_title += "\n" + self.config['description']
             if settings.TITLE and not skip_title:
-                plot_title += " - " + settings.TITLE
-            titles.append(self.plt.suptitle(plot_title, fontsize=14))
+                plot_title += "\n" + settings.TITLE
+            if 'description' in self.config and settings.TITLE and not skip_title:
+                y=1.01
+            titles.append(self.plt.suptitle(plot_title, fontsize=14, y=y))
 
         if settings.ANNOTATE:
             annotation_string = "Local/remote: %s/%s - Time: %s - Length/step: %ds/%.2fs" % (
                 settings.LOCAL_HOST, settings.HOST,
                 settings.TIME,
                 settings.LENGTH, settings.STEP_SIZE)
-            titles.append(self.plt.suptitle(annotation_string,
-                                            x=0.5,
-                                            y=0.005,
+            titles.append(self.plt.gcf().text(0.5, -0.01, annotation_string,
                                             horizontalalignment='center',
                                             verticalalignment='bottom',
                                             fontsize=8))
@@ -543,8 +544,13 @@ class PlotFormatter(Formatter):
     def _do_scaling(self, axis, data, btm, top):
         """Scale the axis to the selected bottom/top percentile"""
         data = [x for x in data if x is not None]
+        if not data:
+            return
         top_percentile = self.np.percentile(data, top)*1.05
         btm_percentile = self.np.percentile(data, btm)*0.95
-        axis.set_ylim(ymin=btm_percentile, ymax=top_percentile)
-        if top_percentile/btm_percentile > 20.0:
-            axis.set_yscale('log')
+        if settings.ZERO_Y:
+            axis.set_ylim(ymin=0, ymax=top_percentile)
+        else:
+            axis.set_ylim(ymin=btm_percentile, ymax=top_percentile)
+            if top_percentile/btm_percentile > 20.0 and settings.LOG_SCALE:
+                axis.set_yscale('log')
